==> atlassian-diagnostics-platform-1.1.14-sources.jar: com/atlassian/diagnostics/internal/platform/monitor/db/JmxDatabasePoolAttributes.java <==
package com.atlassian.diagnostics.internal.platform.monitor.db;

import javax.annotation.Nonnull;

public enum JmxDatabasePoolAttributes {
    APACHE_COMMONS(
            "org.apache.commons.pool2.impl.GenericObjectPool",
            "NumIdle",
            "NumActive",
            "MaxTotal",
            "RemoveAbandonedTimeout"
    ),
    TOMCAT(
            "org.apache.tomcat.dbcp.pool2.impl.GenericObjectPool",
            "NumIdle",
            "NumActive",
            "MaxTotal",
            "RemoveAbandonedTimeout"
    ),
    VIBUR(
            "org.vibur.dbcp.ViburDBCPMonitoring",
            "PoolRemainingCreated",
            "PoolTaken",
            "PoolMaxSize",
            ""
    ),
    HIKARI(
            "com.zaxxer.hikari.pool.HikariPool",
            "IdleConnections",
            "ActiveConnections",
            "TotalConnections",
            ""
    ),
    UNKNOWN("", "", "", "", "");

    public final String instanceOfQuery;
    public final String idleConnectionsAttributeName;
    public final String activeConnectionsAttribute;
    public final String maxConnectionsAttribute;
    public final String abandonedTimeoutAttributeName;

    JmxDatabasePoolAttributes(@Nonnull final String instanceOfQuery,
                              @Nonnull final String idleConnectionsAttributeName,
                              @Nonnull final String activeConnectionsAttributeName,
                              @Nonnull final String maxConnectionsAttributeName,
                              @Nonnull final String abandonedTimeoutAttributeName) {
        this.instanceOfQuery = instanceOfQuery;
        this.idleConnectionsAttributeName = idleConnectionsAttributeName;
        this.activeConnectionsAttribute = activeConnectionsAttributeName;
        this.maxConnectionsAttribute = maxConnectionsAttributeName;
        this.abandonedTimeoutAttributeName = abandonedTimeoutAttributeName;
    }
}

==> atlassian-diagnostics-platform-5.0.0-sources.jar: com/atlassian/diagnostics/internal/platform/monitor/db/JmxDatabasePoolAttributes.java <==
package com.atlassian.diagnostics.internal.platform.monitor.db;

import javax.annotation.Nonnull;

public enum JmxDatabasePoolAttributes {
    APACHE_COMMONS(
            "org.apache.commons.pool2.impl.GenericObjectPool",
            "NumIdle",
            "NumActive",
            "MaxTotal",
            "RemoveAbandonedTimeout"
    ),
    TOMCAT(
            "org.apache.tomcat.dbcp.pool2.impl.GenericObjectPool",
            "NumIdle",
            "NumActive",
            "MaxTotal",
            "RemoveAbandonedTimeout"
    ),
    VIBUR(
            "org.vibur.dbcp.ViburDBCPMonitoring",
            "PoolRemainingCreated",
            "PoolTaken",
            "PoolMaxSize",
            ""
    ),
    HIKARI(
            "com.zaxxer.hikari.pool.HikariPool",
            "IdleConnections",
            "ActiveConnections",
            "TotalConnections",
            ""
    ),
    C3P0(
            "com.mchange.v2.c3p0.management.DynamicPooledDataSourceManagerMBean",
            "numIdleConnections",
            "numBusyConnections",
            "numConnections",
            ""
    ),
    UNKNOWN("", "", "", "", "");

    public final String instanceOfQuery;
    public final String idleConnectionsAttributeName;
    public final String activeConnectionsAttribute;
    public final String maxConnectionsAttribute;
    public final String abandonedTimeoutAttributeName;

    JmxDatabasePoolAttributes(@Nonnull final String instanceOfQuery,
                              @Nonnull final String idleConnectionsAttributeName,
                              @Nonnull final String activeConnectionsAttributeName,
                              @Nonnull final String maxConnectionsAttributeName,
                              @Nonnull final String abandonedTimeoutAttributeName) {
        this.instanceOfQuery = instanceOfQuery;
        this.idleConnectionsAttributeName = idleConnectionsAttributeName;
        this.activeConnectionsAttribute = activeConnectionsAttributeName;
        this.maxConnectionsAttribute = maxConnectionsAttributeName;
        this.abandonedTimeoutAttributeName = abandonedTimeoutAttributeName;
    }
}
